from django.urls import path

from . import views

urlpatterns = [
    path('', views.index, name='index'),
    path('inserimento/', views.inserimento, name='inserimento'),
    path('utenti/', views.utenti, name='utenti'),
]


# Generated by Django 4.1.2 on 2022-10-26 08:51

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Utenza',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('CF', models.CharField(max_length=200)),
                ('Nome', models.CharField(max_length=200)),
                ('Cognome', models.CharField(max_length=200)),
                ('DataNascita', models.DateTimeField()),
            ],
        ),
    ]



import datetime
from django.db import models

class Utenza(models.Model):
    CF = models.CharField(max_length=200)
    Nome=models.CharField(max_length=200)
    Cognome=models.CharField(max_length=200)
    DataNascita=models.DateField()

    def __str__(self):
        return self.CF

    def getAnnoFromCF(self):
        year = self.CF[6] + self.CF[7]
        currentYear = datetime.date.strftime(datetime.date.today(), "%Y")
        lastDigitCurrentYear = currentYear[2] + currentYear[3]
        if (int(year) <= int(lastDigitCurrentYear) and int(year) >= 0):
            return datetime.date.strftime(datetime.date(int("20"+year), 1, 1), "%Y")
        return datetime.date.strftime(datetime.date(int("19"+year), 1, 1), "%Y")


from pathlib import Path
import os

# Build paths inside the project like this: BASE_DIR / 'subdir'.
BASE_DIR = Path(__file__).resolve().parent.parent

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = os.environ.get('DJANGO_SECRET_KEY')

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = False

ALLOWED_HOSTS = ['localhost', '127.0.0.1', 'gruppo-itis.herokuapp.com']

# Application definition

INSTALLED_APPS = [
    'miaApplicazione.apps.MiaapplicazioneConfig',
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF = 'mioProgetto.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'mioProgetto.wsgi.application'

# Database

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': BASE_DIR / 'db.sqlite3',
    }
}

# Password validation

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]

# Internationalization

LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'CET'

USE_I18N = True

USE_TZ = True

# Static files (CSS, JavaScript, Images)

STATIC_URL = '/static/'
STATIC_ROOT = os.path.join(BASE_DIR, 'staticfiles')
STATICFILES_DIRS = [os.path.join(BASE_DIR, 'static'), ]

# Default primary key field type

DEFAULT_AUTO_FIELD = 'django.db.models.BigAutoField'



# Generated by Django 4.1.2 on 2022-10-26 09:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('miaApplicazione', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='utenza',
            name='DataNascita',
            field=models.DateField(),
        ),
    ]



from django.shortcuts import render
from django.http import HttpResponse
from .models import Utenza

def index(_):
    return HttpResponse("Benvenuti nel progetto del gruppo ITIS")
   
def utenti(request):
    utenza = Utenza.objects.all()
    return render(request, 'utenti.html', {'utenza': utenza})

def inserimento(request):
    try:
        if request.method == 'POST' and request.POST.get('CF'):
            post = Utenza()
            post.CF = request.POST.get('CF')
            post.Nome = request.POST.get('Nome')
            post.Cognome = request.POST.get('Cognome')
            post.DataNascita = request.POST.get('DataNascita')
            post.save()
            return utenti(request)
        return render(request, 'inserimento.html')
    except Exception:
        return render(request,'inserimento.html')



from setuptools import setup, find_packages

setup(
    name="mioProgetto",
    version="0.4",
    description="mioProgetto",
    long_description="mioProgetto",
    long_description_content_type='text/x-rst',
    url="https://gitlab.com/magni5/2022_assignment1_itis.git",
    author="Gruppo ITIS",
    packages=find_packages(),
    python_requires='>=3',
)
